@@ -5,7 +5,8 @@ use Devel::CheckLib;
 
 extends 'Dist::Zilla::Plugin::MakeMaker::Awesome';
 
-my $ccflags = `llvm-config --cflags`;
+my $llvmc   = $ENV{LLVM_CONFIG} || 'llvm-config';
+my $ccflags = `$llvmc --cflags`; chomp $ccflags;
 
 override _build_MakeFile_PL_template => sub {
 	my ($self) = @_;
